## List of entity types

|Name|Description|
|---|---|
|cluster-domclient|Metrics about clusters in the perspective of VM consumption.|
|cluster-domcompmgr|Metrics about clusters in the perspective of vSAN backend.|
|host-domclient|Metrics about hosts in the perspective of VM consumption|
|host-domcompmgr|Metrics about hosts in the perspective of vSAN backend.|
|cache-disk|Metrics about Cache-tier disks|
|capacity-disk|Metrics about Capacity-tier disks|
|disk-group|Metrics about disk groups.|
|vscsi|Metrics for Virtual SCSI of virtual machines|
|virtual-machine|Metrics for virtual machines|
|virtual-disk|Metrics for virtual disks.|
|vsan-vnic-net|Metrics for vSAN VMkernel Network Adapter.|
|vsan-host-net|Metrics for vSAN Host Network.|
|vsan-pnic-net|Metrics for vSAN physical NIC.|
|vsan-iscsi-host|Metrics for all vSAN iSCSI targets on this ESXi host.|
|vsan-iscsi-target|Metrics for all LUNs on a vSAN iSCSI target.|
|vsan-iscsi-lun|Metrics for a vSAN iSCSI LUN.|

## List of metrics for each entity type

### cluster-domclient

Metrics about clusters in the perspective of VM consumption.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|Read IOPS consumed by all vSAN clients in the cluster, such as virtual machines, stats object, etc.|
|iopsWrite|Write IOPS|number|Write IOPS consumed by all vSAN clients in the cluster, such as virtual machines, stats object, etc.|
|throughputRead|Read Throughput|rate_bytes|Read Throughput consumed by all vSAN clients in the cluster, such as virtual machines, stats object, etc.|
|throughputWrite|Write Throughput|rate_bytes|Write Throughput consumed by all vSAN clients in the cluster, such as virtual machines, stats object, etc.|
|latencyAvgRead|Read Latency|time_ms|Average read latency of IOs generated by all vSAN clients in the cluster, such as virtual machines, stats object, etc.|
|latencyAvgWrite|Write Latency|time_ms|Average write latency of IOs generated by all vSAN clients in the cluster, such as virtual machines, stats object, etc.|
|congestion|Congestions|number|Congestions of IOs generated by all vSAN clients in the cluster, such as virtual machines, stats object, etc.|
|oio|Outstanding IO|number|Outstanding IO from all vSAN clients in the cluster, such as virtual machines, stats object, etc.|

### cluster-domcompmgr

Metrics about clusters in the perspective of vSAN backend.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|vSAN cluster read IOPS in the perspective of vSAN backend.|
|iopsResyncRead|Resync Read IOPS|number|vSAN cluster read IOPS of resync traffic includes policy change, repair, maintenance mode / evacuation and rebalance from resyncing objects in the perspective of vSAN backend.|
|iopsWrite|Write IOPS|number|vSAN cluster write IOPS in the perspective of vSAN backend.|
|iopsRecWrite|Recovery Write IOPS|number|vSAN cluster recovery write IOPS in the perspective of vSAN backend.|
|throughputRead|Read Throughput|rate_bytes|vSAN cluster read throughput in the perspective of vSAN backend.|
|tputResyncRead|Resync Read Throughput|rate_bytes|vSAN cluster read throughput of resync traffic includes policy change, repair, maintenance mode / evacuation and rebalance from resyncing objects in the perspective of vSAN backend.|
|throughputWrite|Write Throughput|rate_bytes|vSAN cluster write throughput in the perspective of vSAN backend.|
|throughputRecWrite|Recovery Write Throughput|rate_bytes|vSAN cluster recovery write throughput in the perspective of vSAN backend.|
|latencyAvgRead|Read Latency|time_ms|vSAN cluster average read latency in the perspective of vSAN backend.|
|latAvgResyncRead|Resync Read Latency|time_ms|vSAN cluster read average latency of resync traffic includes policy change, repair, maintenance mode / evacuation and rebalance from resyncing objects in the perspective of vSAN backend.|
|latencyAvgWrite|Write Latency|time_ms|vSAN cluster average write latency in the perspective of vSAN backend.|
|latencyAvgRecWrite|Recovery Write Latency|time_ms|vSAN cluster recovery write average latency in the perspective of vSAN backend.|
|congestion|Congestions|number|vSAN cluster congestions in the perspective of vSAN backend|
|oio|Outstanding IO|number|vSAN cluster outstanding IO in the perspective of vSAN backend|

### host-domclient

Metrics about hosts in the perspective of VM consumption

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|Read IOPS consumed by all vSAN clients in the host, such as virtual machines, stats object, etc.|
|iopsWrite|Write IOPS|number|Write IOPS consumed by all vSAN clients in the host, such as virtual machines, stats object, etc.|
|throughputRead|Read Throughput|rate_bytes|Read Throughput consumed by all vSAN clients in the host, such as virtual machines, stats object, etc.|
|throughputWrite|Write Throughput|rate_bytes|Write Throughput consumed by all vSAN clients in the host, such as virtual machines, stats object, etc.|
|latencyAvgRead|Read Latency|time_ms|Average read latency of IOs generated by all vSAN clients in the host, such as virtual machines, stats object, etc.|
|latencyAvgWrite|Write Latency|time_ms|Average write latency of IOs generated by all vSAN clients in the host, such as virtual machines, stats object, etc.|
|clientCacheHits|Local Client Cache Hit IOPS|number|Average local client cache read IOPS.|
|clientCacheHitRate|Local Client Cache Hit Rate|percentage|Percentage of read IOs which could be satisfied by the local client cache.|
|congestion|Congestions|number|Congestions of IOs generated by all vSAN clients in the host, such as virtual machines, stats object, etc.|
|oio|Outstanding IO|number|Outstanding IO from all vSAN clients in the host, such as virtual machines, stats object, etc.|

### host-domcompmgr

Metrics about hosts in the perspective of vSAN backend.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|vSAN host read IOPS in the perspective of vSAN backend.|
|iopsWrite|Write IOPS|number|vSAN host write IOPS in the perspective of vSAN backend.|
|throughputRead|Read Throughput|rate_bytes|vSAN host read throughput in the perspective of vSAN backend.|
|throughputWrite|Write Throughput|rate_bytes|vSAN host write throughput in the perspective of vSAN backend.|
|latencyAvgRead|Read Latency|time_ms|vSAN host read IO average latency in the perspective of vSAN backend.|
|latencyAvgWrite|Write Latency|time_ms|vSAN host write IO average latency in the perspective of vSAN backend.|
|iopsResyncRead|Resync Read IOPS|number|vSAN host read IOPS of resync traffic includes policy change, repair, maintenance mode / evacuation and rebalance from resyncing objects in the perspective of vSAN backend.|
|iopsRecWrite|Recovery Write IOPS|number|vSAN host recovery write IOPS in the perspective of vSAN backend.|
|tputResyncRead|Resync Read Throughput|rate_bytes|vSAN host read throughput of resync traffic includes policy change, repair, maintenance mode / evacuation and rebalance from resyncing objects in the perspective of vSAN backend.|
|throughputRecWrite|Recovery Write Throughput|rate_bytes|vSAN host recovery write throughput in the perspective of vSAN backend.|
|latAvgResyncRead|Resync Read Latency|time_ms|vSAN host read average latency of resync traffic includes policy chane, repair, maintenance mode / evacuation and rebalance from resyncing objects in the perspective of vSAN backend.|
|latencyAvgRecWrite|Recovery Write Latency|time_ms|vSAN host recovery write IO average latency in the perspective of vSAN backend.|
|congestion|Congestions|number|vSAN host Congestions in the perspective of vSAN backend.|
|oio|Outstanding IO|number|vSAN host Outstanding IO in the perspective of vSAN backend.|

### cache-disk

Metrics about Cache-tier disks

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsDevRead|Physical-layer Read IOPS|number|vSAN disk physical/firmware layer read IOPS.|
|iopsDevWrite|Physical-layer Write IOPS|number|vSAN disk physical/firmware layer write IOPS.|
|throughputDevRead|Physical-layer Read Throughput|rate_bytes|vSAN disk physical/firmware layer read throughput.|
|throughputDevWrite|Physical-layer Write Throughput|rate_bytes|vSAN disk physical/firmware layer write throughput.|
|latencyDevRead|Physical-layer Read Latency|time_ms|vSAN disk physical/firmware layer read latency.|
|latencyDevWrite|Physical-layer Write Latency|time_ms|vSAN disk physical/firmware layer write latency.|
|latencyDevGAvg|Guest Average Latency|time_ms|vSAN disk Guest IO latency (total latency).|
|latencyDevDAvg|Device Average Latency|time_ms|vSAN disk IO device latency (from HBA to backend storage).|

### capacity-disk

Metrics about Capacity-tier disks

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsDevRead|Physical-layer Read IOPS|number|vSAN disk physical/firmware layer read IOPS.|
|iopsDevWrite|Physical-layer Write IOPS|number|vSAN disk physical/firmware layer write IOPS.|
|throughputDevRead|Physical-layer Read Throughput|rate_bytes|vSAN disk physical/firmware layer read throughput.|
|throughputDevWrite|Physical-layer Write Throughput|rate_bytes|vSAN disk physical/firmware layer write throughput.|
|latencyDevRead|Physical-layer Read Latency|time_ms|vSAN disk physical/firmware layer read latency.|
|latencyDevWrite|Physical-layer Write Latency|time_ms|vSAN disk physical/firmware layer write latency.|
|latencyDevGAvg|Guest Average Latency|time_ms|vSAN disk Guest IO latency (total latency).|
|latencyDevDAvg|Device Average Latency|time_ms|vSAN disk IO device latency (from HBA to backend storage).|
|iopsRead|vSAN Layer Read IOPS|number|Disk vSAN layer read IOPS.|
|iopsWrite|vSAN Layer Write IOPS|number|Disk vSAN layer write IOPS.|
|latencyRead|vSAN Layer Read Latency|time_ms|Disk vSAN layer read latency.|
|latencyWrite|vSAN Layer Write Latency|time_ms|Disk vSAN layer write latency.|

### disk-group

Metrics about disk groups.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Frontend Read IOPS|number|vSAN disk group (cache tier disk) frontend read IOPS including RC read misses.|
|iopsWrite|Frontend Write IOPS|number|vSAN disk group (cache tier disk) frontend write IOPS.|
|iopsRcRead|Read Cache Read IOPS|number|vSAN disk group (cache tier disk) Read Cache read IOPS.|
|iopsWbWrite|Write Buffer Write IOPS|number|vSAN disk group (cache tier disk) Write Buffer write IOPS.|
|throughputRead|Frontend Read Throughput|rate_bytes|vSAN disk group (cache tier disk) frontend read throughput.|
|throughputWrite|Frontend Write Throughput|rate_bytes|vSAN disk group (cache tier disk) frontend write throughput.|
|latencyAvgRead|Frontend Read Latency|time_ms|vSAN disk group (cache tier disk) frontend read latency.|
|latencyAvgWrite|Frontend Write Latency|time_ms|vSAN disk group (cache tier disk) frontend write latency.|
|latencyRcRead|Read Cache  Read Latency|time_ms|vSAN disk group (cache tier disk) Read Cache read latency.|
|latencyWbWrite|Write Buffer Write Latency|time_ms|vSAN disk group (cache tier disk) Write Buffer write latency.|
|iopsRcWrite|Read Cache Write IOPS|number|vSAN disk group (cache tier disk) Read Cache write IOPS.|
|iopsWbRead|Write Buffer Read IOPS|number|vSAN disk group (cache tier disk) Write Buffer read IOPS.|
|latencyRcWrite|Read Cache Write Latency|time_ms|vSAN disk group (cache tier disk) Read Cache write latency.|
|latencyWbRead|Write Buffer  Read Latency|time_ms|vSAN disk group (cache tier disk) Write Buffer read latency.|
|rcHitRate|Read Cache Hit Rate|percentage|vSAN disk group (cache tier disk) Read Cache Hit Rate.|
|warEvictions|Cache Invalidations|number|Cache lines invalidated due to overwrites.|
|quotaEvictions|Evictions|number|Evictions due to Read Cache contention.|
|wbFreePct|Write Buffer Free Percentage|percentage|vSAN disk group (cache tier disk) Write Buffer free percentage.|
|capacity|Capacity|size_bytes|vSAN disk group capacity.|
|capacityUsed|Used Capacity|size_bytes|vSAN disk group used capacity.|
|capacityReserved|Reserved Capacity|size_bytes|vSAN disk group reserved capacity.|
|rcSize|Read Cache Size|size_bytes|vSAN disk group Read Cache size.|
|wbSize|Write Buffer Size|size_bytes|vSAN disk group Write Buffer size.|
|ssdBytesDrained|Bytes De-stage from SSD|rate_bytes|The throughput of the SSD bytes de-staged from the cache disk to capacity disks|
|zeroBytesDrained|Zero-Bytes De-stage|rate_bytes|The throughput of the zero-bytes de-staged to capacity disks|
|memCongestion|Mem-Congestion|number|vSAN disk group Mem-congestions.|
|slabCongestion|Slab-Congestion|number|vSAN disk group Slab-congestions.|
|ssdCongestion|SSD-Congestion|number|vSAN disk group SSD-congestions.|
|iopsCongestion|IOPS-Congestion|number|vSAN disk group IOPS-congestions.|
|logCongestion|Log-Congestion|number|vSAN disk group Log-congestions.|
|compCongestion|Comp-Congestion|number|vSAN disk group Comp-congestion.|
|oioWrite|Outstanding Write OPs|number|The number of outstanding write operations of the disk group|
|oioRecWrite|Outstanding Recovery Write OPs|number|The number of outstanding recovery write operations of the disk group|
|oioWriteSize|Outstanding Write IO Size|size_bytes|The size of outstanding write IO of the disk group|
|oioRecWriteSize|Outstanding Recovery Write IO Size|size_bytes|The size of outstanding recovery write IO of the disk group|
|iopsDelayPctSched|Delayed IO Percentage|percentage|The percentage of IOs which go though vSAN internal queues.|
|latencyDelaySched|Delayed IO Average Latency|time_ms|The average latency of total IOs which go though vSAN internal queues.|
|latencySchedQueueNS|Latency of Namespace Queue|time_ms|The Latency of the namespace IO queue in the vSAN internal scheduler.|
|latencySchedQueueRec|Latency of Recovery Queue|time_ms|The Latency of the recovery IO queue in the vSAN internal scheduler.|
|latencySchedQueueVM|Latency of VM Queue|time_ms|The Latency of the VM IO queue in the vSAN internal scheduler.|
|latencySchedQueueMeta|Latency of Meta Queue|time_ms|The Latency of the meta IO queue in the vSAN internal scheduler.|
|iopsSched|Total Delayed IOPS|number|The IOPS of total IOs which go through vSAN internal queues.|
|iopsSchedQueueNS|IOPS of Namespace Queue|number|The IOPS of the namespace IO queue in the vSAN internal scheduler.|
|iopsSchedQueueRec|IOPS of Recovery Queue|number|The IOPS of the recovery IO queue in the vSAN internal scheduler.|
|iopsSchedQueueVM|IOPS of VM Queue|number|The IOPS of the VM IO queue in the vSAN internal scheduler.|
|iopsSchedQueueMeta|IOPS of Meta Queue|number|The IOPS of the meta IO queue in the vSAN internal scheduler.|
|throughputSched|Total Queue Throughput|rate_bytes|The throughput of total delayed IO in the vSAN internal scheduler.|
|throughputSchedQueueNS|Throughput of Namespace Queue|rate_bytes|The throughput of the namespace IO queue in the vSAN internal scheduler.|
|throughputSchedQueueRec|Throughput of Recovery Queue|rate_bytes|The throughput of the recovery IO queue in the vSAN internal scheduler.|
|throughputSchedQueueVM|Throughput of VM Queue|rate_bytes|The throughput of the VM IO queue in the vSAN internal scheduler.|
|throughputSchedQueueMeta|Throughput of Meta Queue|rate_bytes|The throughput of the meta IO queue in the vSAN internal scheduler.|
|iopsResyncReadPolicy|Policy Change Read|number|vSAN disk group level read IOPS for resync traffic caused by change of policy.|
|iopsResyncReadDecom|Evacuation Read|number|vSAN disk group level read IOPS for resync traffic caused by maintenance mode and object evacuation.|
|iopsResyncReadRebalance|Rebalance Read|number|vSAN disk group level read IOPS for resync traffic caused by rebalancing objects.|
|iopsResyncReadFixComp|Repair Read|number|vSAN disk group level read IOPS for resync traffic caused by object repair.|
|iopsResyncWritePolicy|Policy Change Write|number|vSAN disk group level write IOPS for resync traffic caused by change of policy.|
|iopsResyncWriteDecom|Evacuation Write|number|vSAN disk group level write IOPS for resync traffic caused by maintenance mode and object evacuation.|
|iopsResyncWriteRebalance|Rebalance Write|number|vSAN disk group level write IOPS for resync traffic caused by rebalancing objects.|
|iopsResyncWriteFixComp|Repair Write|number|vSAN disk group level write IOPS for resync traffic caused by object repair.|
|tputResyncReadPolicy|Policy Change Read|rate_bytes|vSAN disk group level read throughput for resync traffic caused by change of policy.|
|tputResyncReadDecom|Evacuation Read|rate_bytes|vSAN disk group level read throughput for resync traffic caused by maintenance mode and object evacuation.|
|tputResyncReadRebalance|Rebalance Read|rate_bytes|vSAN disk group level read throughput for resync traffic caused by rebalancing objects.|
|tputResyncReadFixComp|Repair Read|rate_bytes|vSAN disk group level read throughput for resync traffic caused by object repair.|
|tputResyncWritePolicy|Policy Change Write|rate_bytes|vSAN disk group level write throughput for resync traffic caused by change of policy.|
|tputResyncWriteDecom|Decommission Write|rate_bytes|vSAN disk group level write throughput for resync traffic caused by maintenance mode and object evacuation.|
|tputResyncWriteRebalance|Rebalance Write|rate_bytes|vSAN disk group level write throughput for resync traffic caused by rebalancing objects.|
|tputResyncWriteFixComp|Repair Write|rate_bytes|vSAN disk group level write throughput for resync traffic caused by object repair.|
|latResyncReadPolicy|Policy Change Read|time_ms|vSAN disk group level read latency for resync traffic caused by change of policy.|
|latResyncReadDecom|Evacuation Read|time_ms|vSAN disk group level read latency for resync traffic caused by maintenance mode and object evacuation.|
|latResyncReadRebalance|Rebalance Read|time_ms|vSAN disk group level read latency for resync traffic caused by rebalancing objects.|
|latResyncReadFixComp|Repair Read|time_ms|vSAN disk group level read latency for resync traffic caused by object repair.|
|latResyncWritePolicy|Policy Change Write|time_ms|vSAN disk group level write latency for resync traffic caused by change of policy.|
|latResyncWriteDecom|Evacuation Write|time_ms|vSAN disk group level write latency for resync traffic caused by maintenance mode and object evacuation.|
|latResyncWriteRebalance|Rebalance Write|time_ms|vSAN disk group level write latency for resync traffic caused by rebalancing objects.|
|latResyncWriteFixComp|Repair Write|time_ms|vSAN disk group level write latency for resync traffic caused by object repair.|

### vscsi

Metrics for Virtual SCSI of virtual machines

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|Virtual machine VSCSI read IOPS.|
|iopsWrite|Write IOPS|number|Virtual machine VSCSI write IOPS.|
|throughputRead|Read Throughput|rate_bytes|Virtual machine VSCSI read throughput.|
|throughputWrite|Write Throughput|rate_bytes|Virtual machine VSCSI write throughput.|
|latencyRead|Read Latency|time_ms|Virtual machine VSCSI read latency.|
|latencyWrite|Write Latency|time_ms|Virtual machine VSCSI write latency.|

### virtual-machine

Metrics for virtual machines

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|Virtual machine read IOPS.|
|iopsWrite|Write IOPS|number|Virtual machine write IOPS.|
|throughputRead|Read Throughput|rate_bytes|Virtual machine read throughput.|
|throughputWrite|Write Throughput|rate_bytes|Virtual machine write throughput.|
|latencyRead|Read Latency|time_ms|Virtual machine read latency.|
|latencyWrite|Write Latency|time_ms|Virtual machine write latency.|

### virtual-disk

Metrics for virtual disks.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsLimit|Normalized IOPS Limit|number|The applied IOPS limit.|
|NIOPS|Normalized IOPS|number|This shows IOPS that are represented using a weighted size of 32KB by default. This means that a 64KB read or write operation represents 2 normalized IO. The weighted size is a configurable parameter.|
|NIOPSDelayed|Delayed Normalized IOPS|number|This is the IOPS for normalized IOs that are delayed.|

### vsan-vnic-net

Metrics for vSAN VMkernel Network Adapter.

|Label|Name|Unit|Description|
|---|---|---|---|
|rxThroughput|Throughput Inbound|rate_bytes|VMkernel Network Adapter Throughput Inbound.|
|txThroughput|Throughput Outbound|rate_bytes|VMkernel Network Adapter Throughput Outbound.|
|rxPackets|Inbound Packets Per Second|number|VMkernel Network Adapter Inbound Packets Per Second.|
|txPackets|Outbound Packets Per Second|number|VMkernel Network Adapter Outbound Packets Per Second.|
|rxPacketsLossRate|Inbound Packets Loss Rate|permille|Percentage of VMkernel Network Adapter Inbound Packets Loss Rate.|
|txPacketsLossRate|Outbound Packets Loss Rate|permille|Percentage of VMkernel Network Adapter Outbound Packets Loss Rate.|

### vsan-host-net

Metrics for vSAN Host Network.

|Label|Name|Unit|Description|
|---|---|---|---|
|rxThroughput|Network Inbound Throughput|rate_bytes|Host Throughput Inbound of All VMkernel Network Adapters Enabled vSAN Traffic.|
|txThroughput|Network Outbound Throughput|rate_bytes|Host Throughput Outbound of All VMkernel Network Adapters Enabled vSAN Traffic.|
|rxPackets|Network Inbound Packets Per Second|number|Host Network Inbound Packets Per Second of All VMkernel Network Adapters Enabled vSAN Traffic.|
|txPackets|Network Outbound Packets Per Second|number|Host Network Outbound Packets Per Second of All VMkernel Network Adapters Enabled vSAN Traffic.|
|rxPacketsLossRate|Network Inbound Packets Loss Rate|permille|Percentage of Host Inbound Packets Loss Rate of All VMkernel Network Adapters Enabled vSAN Traffic.|
|txPacketsLossRate|Network Outbound Packets Loss Rate|permille|Percentage of Host Outbound Packets Loss Rate of All VMkernel Network Adapters Enabled vSAN Traffic.|

### vsan-pnic-net

Metrics for vSAN physical NIC.

|Label|Name|Unit|Description|
|---|---|---|---|
|rxThroughput|pNIC Throughput Inbound|rate_bytes|Physical NIC Throughput Inbound.|
|txThroughput|pNIC Throughput Outbound|rate_bytes|Physical NIC Throughput Outbound.|
|rxPackets|pNIC Inbound Packets Per Second|number|Physical NIC Inbound Packets Per Second.|
|txPackets|pNIC Outbound Packets Per Second|number|Physical NIC Outbound Packets Per Second.|
|rxPacketsLossRate|pNIC Inbound Packets Loss Rate|permille|Percentage of Physical NIC Inbound Packets Loss Rate.|
|txPacketsLossRate|pNIC Outbound Packets Loss Rate|permille|Percentage of Physical NIC Outbound Packets Loss Rate.|

### vsan-iscsi-host

Metrics for all vSAN iSCSI targets on this ESXi host.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|Read IOPS consumed by all vSAN iSCSI targets on this ESXi host.|
|iopsWrite|Write IOPS|number|Write IOPS consumed by all vSAN iSCSI targets on this ESXi host.|
|iopsTotal|Total IOPS|number|Total IOPS consumed by all vSAN iSCSI targets on this ESXi host.|
|bandwidthRead|Read Bandwidth|rate_bytes|Read bandwidth consumed by all vSAN iSCSI targets on this ESXi host.|
|bandwidthWrite|Write Bandwidth|rate_bytes|Write bandwidth consumed by all vSAN iSCSI targets on this ESXi host.|
|bandwidthTotal|Total Bandwidth|rate_bytes|Total bandwidth consumed by all vSAN iSCSI targets on this ESXi host.|
|latencyRead|Read Latency|time_ms|Average read latency of IOs generated by all vSAN iSCSI targets on this ESXi host.|
|latencyWrite|Write Latency|time_ms|Average write latency of IOs generated by all vSAN iSCSI targets on this ESXi host.|
|latencyTotal|Total Latency|time_ms|Average total latency of IOs generated by all vSAN iSCSI targets on this ESXi host.|
|queueDepth|Outstanding IO|number|Outstanding IO from all vSAN iSCSI targets on this ESXi host.|

### vsan-iscsi-target

Metrics for all LUNs on a vSAN iSCSI target.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|Read IOPS consumed by all vSAN iSCSI LUNs on this target.|
|iopsWrite|Write IOPS|number|Write IOPS consumed by all vSAN iSCSI LUNs on this target.|
|iopsTotal|Total IOPS|number|Total IOPS consumed by all vSAN iSCSI LUNs on this target.|
|bandwidthRead|Read Bandwidth|rate_bytes|Read bandwidth consumed by all vSAN iSCSI LUNs on this target.|
|bandwidthWrite|Write Bandwidth|rate_bytes|Write bandwidth consumed by all vSAN iSCSI LUNs on this target.|
|bandwidthTotal|Total Bandwidth|rate_bytes|Total bandwidth consumed by all vSAN iSCSI LUNs on this target.|
|latencyRead|Read Latency|time_ms|Average read latency of IOs generated by all vSAN iSCSI LUNs on this target.|
|latencyWrite|Write Latency|time_ms|Average write latency of IOs generated by all vSAN iSCSI LUNs on this target.|
|latencyTotal|Total Latency|time_ms|Average total latency of IOs generated by all vSAN iSCSI LUNs on this target.|
|queueDepth|Outstanding IO|number|Outstanding IO from all vSAN iSCSI LUNs on this target.|

### vsan-iscsi-lun

Metrics for a vSAN iSCSI LUN.

|Label|Name|Unit|Description|
|---|---|---|---|
|iopsRead|Read IOPS|number|Read IOPS consumed by this vSAN iSCSI LUN.|
|iopsWrite|Write IOPS|number|Write IOPS consumed by this vSAN iSCSI LUN.|
|iopsTotal|Total IOPS|number|Total IOPS consumed by this vSAN iSCSI LUN.|
|bandwidthRead|Read Bandwidth|rate_bytes|Read bandwidth consumed by this vSAN iSCSI LUN.|
|bandwidthWrite|Write Bandwidth|rate_bytes|Write bandwidth consumed by this vSAN iSCSI LUN.|
|bandwidthTotal|Total Bandwidth|rate_bytes|Total bandwidth consumed by this vSAN iSCSI LUN.|
|latencyRead|Read Latency|time_ms|Average read latency of IOs generated by this vSAN iSCSI LUN.|
|latencyWrite|Write Latency|time_ms|Average write latency of IOs generated by this vSAN iSCSI LUN.|
|latencyTotal|Total Latency|time_ms|Average total latency of IOs generated by this vSAN iSCSI LUN.|
|queueDepth|Outstanding IO|number|Outstanding IO from this vSAN iSCSI LUN.|